@@ -32,7 +32,7 @@ package Apache2::AMFWURFLFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "3.09";
+  $VERSION= "3.10";
   my $CommonLib = new Apache2::AMFCommonLib ();
  
   my %Capability;
@@ -59,11 +59,52 @@ package Apache2::AMFWURFLFilter;
   $MobileArray{'brew'}='mobile';
   $MobileArray{'webos'}='mobile';
   $MobileArray{'kddi'}='mobile';
-  $PCArray{'MSIE'}='msie';
-  $PCArray{'MSIE 5'}='msie_5';
-  $PCArray{'MSIE 6'}='msie_6';
-  $PCArray{'MSIE 7'}='msie_7';
-  $PCArray{'MSIE 8'}='msie_8';
+  $MobileArray{'nokia'}='mobile';
+  $MobileArray{'sanyo'}='mobile';
+  $MobileArray{'foma'}='mobile';
+  $MobileArray{'hiptop'}='mobile';
+  $MobileArray{'kindle'}='mobile';
+  $MobileArray{'tablet'}='mobile';
+  $MobileArray{'maemo'}='mobile';
+  $MobileArray{'softbank'}='mobile';
+  $MobileArray{'mobile'}='mobile';
+  $MobileArray{'symbian'}='mobile';
+  $MobileArray{'midp'}='mobile';
+  $MobileArray{'android'}='mobile';
+  $MobileArray{'phone'}='mobile';
+  $MobileArray{'ipod'}='mobile';
+  $MobileArray{'google'}='mobile';
+  $MobileArray{'novarra'}='mobile';
+  $MobileArray{'htc'}='mobile';
+  $MobileArray{'windows ce'}='mobile';
+  $MobileArray{'palm'}='mobile';
+  $MobileArray{'lge'}='mobile';
+  $MobileArray{'brew'}='mobile';
+  $MobileArray{'webos'}='mobile';
+  $MobileArray{'kddi'}='mobile';
+  $MobileArray{'nokia'}='mobile';
+  $MobileArray{'sanyo'}='mobile';
+  $MobileArray{'foma'}='mobile';
+  $MobileArray{'hiptop'}='mobile';
+  $MobileArray{'kindle'}='mobile';
+  $MobileArray{'tablet'}='mobile';
+  $MobileArray{'maemo'}='mobile';
+  $MobileArray{'softbank'}='mobile';
+  $MobileArray{'netfront'}='mobile';
+  $MobileArray{'sony'}='mobile';
+  $MobileArray{'playstation'}='mobile';
+  $MobileArray{'samsung'}='mobile';
+  $MobileArray{'bolt'}='mobile';
+  $MobileArray{'nintendo'}='mobile';
+  $PCArray{'msie'}='msie';
+  $PCArray{'msie 5'}='msie_5';
+  $PCArray{'msie 6'}='msie_6';
+  $PCArray{'msie 7'}='msie_7';
+  $PCArray{'msie 8'}='msie_8';
+  $PCArray{'chrome'}='google_chrome';
+  $PCArray{'chrome/0'}='google_chrome_0';
+  $PCArray{'chrome/1'}='google_chrome_1';
+  $PCArray{'chrome/2'}='google_chrome_2';
   my $mobileversionurl="none";
   my $fullbrowserurl="none";
   my $redirecttranscoder="true";
@@ -132,8 +173,6 @@ package Apache2::AMFWURFLFilter;
 	  $CommonLib->printLog("AMFMobileHome not exist (AMFMobileHome is deprecated).	Please set the variable AMFMobileHome into httpd.conf");
 	  ModPerl::Util::exit();
   }
-  
-
 sub loadConfigFile {
 	my ($fileWurfl) = @_;
 	my $null="";
@@ -444,7 +483,7 @@ sub parsePatchFile {
 		 } 
 	     if ($record =~ /\<device/o) {
 	        if (index($record,'user_agent') > 0 ) {
-	           $ua=substr($record,index($record,'user_agent') + 12,index($record,'"',index($record,'user_agent')+ 13)- index($record,'user_agent') - 12);
+	           $ua=lc(substr($record,index($record,'user_agent') + 12,index($record,'"',index($record,'user_agent')+ 13)- index($record,'user_agent') - 12));
 	        }	        
 	        if (index($record,'id') > 0 ) {
 	           $id=substr($record,index($record,'id') + 4,index($record,'"',index($record,'id')+ 5)- index($record,'id') - 4);	
@@ -547,9 +586,13 @@ sub IdentifyPCUAMethod {
   if ($id_find) {}else{$id_find="";};
   if ($id_find eq "") { 
 	foreach $pair (%PatchArray_id)
-	{  
+	{
+	     my $value=index($UserAgent,$pair);
+	     
 	     if (index($UserAgent,$pair) > -1) {
-		      $id_find=$PatchArray_id{$pair};
+		      if ($PatchArray_id{$pair}) {
+			$id_find=$PatchArray_id{$pair};
+		      }
 	     }
 	}
   }
